==> dazuko-0.4.tgz: dazuko-0.4/php_dazuko.h <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2004 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.0 of the PHP license,       |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_0.txt.                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Oliver Welter <areaz@dotgeek.org>                            |
  +----------------------------------------------------------------------+
*/

/* $Id: header,v 1.15 2004/01/08 16:46:52 sniper Exp $ */

#ifndef PHP_DAZUKO_H
#define PHP_DAZUKO_H

extern zend_module_entry dazuko_module_entry;
#define phpext_dazuko_ptr &dazuko_module_entry

#ifdef PHP_WIN32
#define PHP_DAZUKO_API __declspec(dllexport)
#else
#define PHP_DAZUKO_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

PHP_MINIT_FUNCTION(dazuko);
PHP_MSHUTDOWN_FUNCTION(dazuko);
PHP_RINIT_FUNCTION(dazuko);
PHP_RSHUTDOWN_FUNCTION(dazuko);
PHP_MINFO_FUNCTION(dazuko);

PHP_FUNCTION(dazuko_module_loaded);
PHP_FUNCTION(dazuko_fetch_result);
PHP_FUNCTION(dazuko_fetch_thread);
PHP_FUNCTION(dazuko_flush_result);

PHP_FUNCTION(dazuko_return_access);
PHP_FUNCTION(dazuko_get_access);

PHP_FUNCTION(dazuko_thread_return_access);
PHP_FUNCTION(dazuko_thread_get_access);

PHP_FUNCTION(dazuko_register);
PHP_FUNCTION(dazuko_unregister);
PHP_FUNCTION(dazuko_set_accessmask);
PHP_FUNCTION(dazuko_include_path);
PHP_FUNCTION(dazuko_exclude_path);
PHP_FUNCTION(dazuko_remove_paths);

PHP_FUNCTION(dazuko_thread_register);
PHP_FUNCTION(dazuko_thread_unregister);
PHP_FUNCTION(dazuko_thread_set_accessmask);
PHP_FUNCTION(dazuko_thread_include_path);
PHP_FUNCTION(dazuko_thread_exclude_path);
PHP_FUNCTION(dazuko_thread_remove_paths);

#ifdef ZTS
#define DAZUKO_G(v) TSRMG(dazuko_globals_id, zend_dazuko_globals *, v)
#else
#define DAZUKO_G(v) (dazuko_globals.v)
#endif

#endif	/* PHP_DAZUKO_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> dazuko-0.41.tgz: dazuko-0.41/php_dazuko.h <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2004 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.0 of the PHP license,       |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_0.txt.                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Oliver Welter <areaz2@php.net>                               |
  +----------------------------------------------------------------------+
*/

/* $Id: php_dazuko.h,v 1.2 2004/10/05 16:12:02 areaz2 Exp $ */

#ifndef PHP_DAZUKO_H
#define PHP_DAZUKO_H

extern zend_module_entry dazuko_module_entry;
#define phpext_dazuko_ptr &dazuko_module_entry

#ifdef PHP_WIN32
#define PHP_DAZUKO_API __declspec(dllexport)
#else
#define PHP_DAZUKO_API
#endif

#ifdef ZTS
#include "TSRM.h"
#endif

PHP_MINIT_FUNCTION(dazuko);
PHP_MSHUTDOWN_FUNCTION(dazuko);
PHP_RINIT_FUNCTION(dazuko);
PHP_RSHUTDOWN_FUNCTION(dazuko);
PHP_MINFO_FUNCTION(dazuko);

PHP_FUNCTION(dazuko_module_loaded);
PHP_FUNCTION(dazuko_fetch_result);
PHP_FUNCTION(dazuko_fetch_thread);
PHP_FUNCTION(dazuko_flush_result);

PHP_FUNCTION(dazuko_return_access);
PHP_FUNCTION(dazuko_get_access);

PHP_FUNCTION(dazuko_thread_return_access);
PHP_FUNCTION(dazuko_thread_get_access);

PHP_FUNCTION(dazuko_register);
PHP_FUNCTION(dazuko_unregister);
PHP_FUNCTION(dazuko_set_accessmask);
PHP_FUNCTION(dazuko_include_path);
PHP_FUNCTION(dazuko_exclude_path);
PHP_FUNCTION(dazuko_remove_paths);

PHP_FUNCTION(dazuko_thread_register);
PHP_FUNCTION(dazuko_thread_unregister);
PHP_FUNCTION(dazuko_thread_set_accessmask);
PHP_FUNCTION(dazuko_thread_include_path);
PHP_FUNCTION(dazuko_thread_exclude_path);
PHP_FUNCTION(dazuko_thread_remove_paths);

#ifdef ZTS
#define DAZUKO_G(v) TSRMG(dazuko_globals_id, zend_dazuko_globals *, v)
#else
#define DAZUKO_G(v) (dazuko_globals.v)
#endif

#endif	/* PHP_DAZUKO_H */


/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
